<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Category</name>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="362"/>
        <source>All Fonts</source>
        <translation>Všechna písma</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="363"/>
        <source>System</source>
        <translation>Systém</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="364"/>
        <source>User</source>
        <translation>Uživatel</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="365"/>
        <source>Favorites</source>
        <translation>Oblíbené</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="366"/>
        <source>Active</source>
        <translation>Aktivní</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="367"/>
        <source>Chinese</source>
        <translation>čínština</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dsplitlistwidget.cpp" line="368"/>
        <source>Monospaced</source>
        <translation>Všechny znaky stejně široké</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="139"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="550"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou smazána</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="544"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="563"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou zapnuta</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="565"/>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 je množina písem. Pokud budete pokračovat, všechna písma v ní budou vypnuta</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="576"/>
        <source>Enable</source>
        <comment>button</comment>
        <translation>Povolit</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="578"/>
        <source>Disable</source>
        <comment>button</comment>
        <translation>Zakázat</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="467"/>
        <source>Apply to all selected font families</source>
        <translation>Použít na všechny vybrané rodiny písma</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="480"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="103"/>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="114"/>
        <source>Same version installed</source>
        <translation>Nainstalována stejná verze</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="125"/>
        <source>System Font</source>
        <translation>Písmo Systému</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="371"/>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="384"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="403"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="423"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="441"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="521"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="326"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="342"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="358"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1654"/>
        <source>%1 font installed</source>
        <translation>Nainstalováno %1 písmo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1656"/>
        <source>%1 fonts installed</source>
        <translation>Nainstalováno %1 písem</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="474"/>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="562"/>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1661"/>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>Nepodařilo se nainstalovat %1 písmo. Není dost volného místa na disku</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="1663"/>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>Nepodařilo se nainstalovat %1 písem. Není dost volného místa na disku</translation>
    </message>
    <message>
        <location filename="../libdeepin-font-manager/dcopyfilesmanager.h" line="12"/>
        <source>Fonts</source>
        <translation>Písma</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontwidget.cpp" line="127"/>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="229"/>
        <source>This font will not be available to applications</source>
        <translation>Toto písmo nebude dostupné aplikacím</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="231"/>
        <source>These fonts will not be available to applications</source>
        <translation>Tato písma nebude dostupná aplikacím</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="234"/>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>Dalších %1 systémových písem není možné smazat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="237"/>
        <source>The font "%1" in use cannot be deleted</source>
        <translation>Písmo „%1“ je právě používáno a není ho proto možné smazat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="240"/>
        <source>The other %1 system fonts and the font "%2" in use cannot be deleted</source>
        <translation>Dalších %1 systémových písem a písmo „%2“ je právě používáno a není ho proto možné smazat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="204"/>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>Opravdu chcete %1 písem smazat?</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfdeletedialog.cpp" line="140"/>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="74"/>
        <source>Deleting fonts, please wait...</source>
        <translation>Mazání písem – čekejte prosím…</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="151"/>
        <source>Font Verification</source>
        <translation>Ověření písma</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="252"/>
        <source>No fonts to be installed</source>
        <translation>Žádná písma k instalaci</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="186"/>
        <source>Exit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallerrordialog.cpp" line="187"/>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <location filename="../libdeepin-font-manager/dfontpreviewitemdef.h" line="15"/>
        <source>Don't let your dreams be dreams</source>
        <translation>Nedovolte svým snům zůstat pouze sny</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="131"/>
        <source>Basic info</source>
        <translation>Základní údaje</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="60"/>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="62"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="66"/>
        <source>Version</source>
        <translation>Verze</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="72"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="73"/>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="78"/>
        <source>Full name</source>
        <translation>Úplný název</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="79"/>
        <source>Ps name</source>
        <translation>PostScript název</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="80"/>
        <source>Trademark</source>
        <translation>Registrovaná obchodní značka</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="123"/>
        <source>Copyright</source>
        <translation>Autorský právo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontinfoscrollarea.cpp" line="124"/>
        <source>License Description</source>
        <translation>Popis licence</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="60"/>
        <source>Font Manager</source>
        <translation>Správa písem</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/main.cpp" line="61"/>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>Správa písem pomáhá uživatelům instalovat a spravovat písma.</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontspinnerwidget.cpp" line="37"/>
        <source>Loading fonts, please wait...</source>
        <translation>Načítání písem – čekejte prosím…</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2093"/>
        <source>The font exported to your desktop</source>
        <translation>Písmo exportováno na vaši plochu</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2095"/>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 písem exportováno na vaši plochu</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2099"/>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>Nepodařilo se exportovat 1 písmo. Není dost volného místa na disku.</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2102"/>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>Nepodařilo se exportovat %1 písem. Není dost volného místa na disku.</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="63"/>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="71"/>
        <source>Enable</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="297"/>
        <source>Disable</source>
        <translation>Zakázat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="73"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="77"/>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="278"/>
        <source>Unfavorite</source>
        <translation>Odstranit z oblíbených</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="80"/>
        <source>Details</source>
        <translation>Podrobnosti</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="83"/>
        <source>Display in file manager</source>
        <translation>Zobrazit ve správci souborů</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontmenumanager.cpp" line="75"/>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1875"/>
        <source>deactivated</source>
        <translation>vypnuto</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1877"/>
        <source>The fonts have been deactivated</source>
        <translation>Písma byla deaktivována</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1867"/>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 je využíváno, takže ho nyní nelze zakázat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1869"/>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>Systémová písma a ta, které jsou právě využívány, není možné smazat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/interfaces/dfontpreviewlistview.cpp" line="1871"/>
        <source>You cannot disable system fonts</source>
        <translation>Systémová písma není možné zakázat</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="130"/>
        <source>Install Font</source>
        <translation>Nainstalovat písmo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfinstallnormalwindow.cpp" line="143"/>
        <source>Verifying...</source>
        <translation>Ověřování…</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="77"/>
        <source>Unknown</source>
        <translation>Neznámý</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="206"/>
        <source>Broken file</source>
        <translation>Poškozený soubor</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="227"/>
        <source>Installed</source>
        <translation>Nainstalováno</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="232"/>
        <source>Not Installed</source>
        <translation>Nenainstalováno</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfquickinstallwindow.cpp" line="127"/>
        <source>Install Font</source>
        <translation>Nainstalovat písmo</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="653"/>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="838"/>
        <source>No search results</source>
        <translation>Žádné výsledky hledání</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="860"/>
        <source>No fonts</source>
        <translation>Žádná písma</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2275"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2280"/>
        <source>Display shortcuts</source>
        <translation>Zobrazit klávesové zkratky</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2281"/>
        <source>Page up</source>
        <translation>O stránku nahoru</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2282"/>
        <source>Page down</source>
        <translation>O stránku dolů</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2285"/>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2286"/>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2287"/>
        <source>Favorite</source>
        <translation>Přidat do oblíbených</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2288"/>
        <source>Unfavorite</source>
        <translation>Odstranit z oblíbených</translation>
    </message>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="2289"/>
        <source>Font info</source>
        <translation>Informace o písmu</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <location filename="../deepin-font-manager/views/dfontmgrmainwindow.cpp" line="901"/>
        <source>Input preview text</source>
        <translation>Zadejte náhledový text</translation>
    </message>
</context>
</TS>
